/*
  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-only
*/

#ifndef KSIEVEUITESTSCAPABILITY_H
#define KSIEVEUITESTSCAPABILITY_H

#include <QStringList>

namespace KSieveUi
{
namespace Test
{
QStringList fullCapabilitiesList();
}
}

#endif // KSIEVEUITESTSCAPABILITY_H
